clearAllSeenState method
Clears seen state for all stories in the widget.
If refreshList is true, the widget list refreshes to reflect the change.
Implementation
Future<void> clearAllSeenState({bool refreshList = true}) async {
await _methodChannel?.invokeMethod(Method.CLEAR_ALL_SEEN_STATE, {'refreshList': refreshList});
}