clearSeenState method

Future<void> clearSeenState(
  1. int storyId, {
  2. bool refreshList = true,
})

Clears seen state for a single story by storyId.

If refreshList is true, the widget list refreshes to reflect the change.

Implementation

Future<void> clearSeenState(int storyId, {bool refreshList = true}) async {
  await _methodChannel?.invokeMethod(Method.CLEAR_SEEN_STATE, {
    'storyId': storyId,
    'refreshList': refreshList,
  });
}